"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const duplicateSymbols = {
    rule: (context) => __awaiter(void 0, void 0, void 0, function* () {
        var duplicates = [];
        for (const symbol of context.utils.objects.symbolMaster) {
            var existingElement = duplicates.find((element) => element.name == symbol.name);
            if (existingElement != null)
                existingElement.number++;
            else
                duplicates.push({ name: symbol.name, number: 1, local: true, foreign: false, symbol });
        }
        for (const msimmutablesymbol of context.utils.foreignObjects.MSImmutableForeignSymbol) {
            var symbol = msimmutablesymbol.symbolMaster;
            var existingElement = duplicates.find((element) => element.name == symbol.name);
            if (existingElement != null) {
                existingElement.number++;
                existingElement.foreign = true;
            }
            else {
                duplicates.push({ name: symbol.name, number: 1, local: false, foreign: true, symbol });
            }
        }
        for (const duplicate of (duplicates.filter((element) => element.number > 1))) {
            context.utils.report(`Symbol ${duplicate.name} duplicate ${duplicate.number} times`);
            context.utils.report("", duplicate.symbol);
        }
    }),
    name: 'symbols-no-duplicated',
    title: 'Duplicate symbols',
    description: 'Reports duplicate symbols in your design file.',
};
const assistant = () => __awaiter(void 0, void 0, void 0, function* () {
    return {
        name: 'symbols-no-duplicated',
        rules: [duplicateSymbols],
        title: (`Symbols should not be duplicated`),
        description: (`Duplicated symbols could cause inconsistencies and make updating components hard to manage.`),
        config: {
            rules: {
                'symbols-no-duplicated': { active: true },
            },
        },
    };
});
exports.default = assistant;
